@@ -18,6 +18,7 @@ from pyramid.request import Request
 from pyramid.response import FileResponse
 from datetime import datetime
 from .. import security, models, storage
+from ..resource import get_identifier
 from .files import access_file_by_user
 from sqlalchemy import and_
 
@@ -31,9 +32,10 @@ from sqlalchemy import and_
 def get_file_url(request: Request) -> HTTPTemporaryRedirect:
     """Redirects to a temporary, pre-sign HTTP-URL for downloading a file.
     """
-    file_id = request.openapi_validated.parameters.path['id']
-    expires_after = request.openapi_validated.parameters.query['expires']
-    auth_user = security.revalidate_user(request)
+    file_id         = request.openapi_validated.parameters.path['id']
+    expires_after   = request.openapi_validated.parameters.query['expires']
+    auth_user       = security.revalidate_user(request)
+    redirect        = request.openapi_validated.parameters.query['redirect']
 
     # get file from db:
     db_file = access_file_by_user(
@@ -43,13 +45,22 @@ def get_file_url(request: Request) -> HTTPTemporaryRedirect:
     )
 
     # retrieve URL:
-    url = storage.get_download_url(
+    url, expires_at = storage.get_download_url(
         request=request,
         db_file=db_file,
         expires_after=expires_after
     )
 
-    return HTTPTemporaryRedirect(url)
+    response = {
+            'fileId' : get_identifier(db_file),
+            'fileUrl' : f"{request.host_url}{url}",
+            'expires' : expires_at.isoformat() + "+00:00"
+            }
+
+    if redirect:
+        return HTTPTemporaryRedirect(url, json_body=response)
+    else:
+        return HTTPOk(json_body=response)
 
 
 @view_config(
@@ -70,7 +81,7 @@ def download_by_token(request: Request) -> HTTPOk:
     db_token = db.query(models.DownloadToken).filter(
         and_(
             models.DownloadToken.value == hashed_token,
-            models.DownloadToken.expires > datetime.now()
+            models.DownloadToken.expires > datetime.utcnow()
         )
     ).one_or_none()
 
