@@ -14,8 +14,6 @@
 
 import argparse
 import sys
-import random
-import uuid
 
 from pyramid.paster import bootstrap, setup_logging
 from sqlalchemy.exc import OperationalError
@@ -23,6 +21,7 @@ from sqlalchemy.exc import OperationalError
 from ..security import hash_password, hash_token
 from ..models import User, Group, MetaDatum, DateTimeMode, ApiKey
 
+
 def parse_args(argv):
     parser = argparse.ArgumentParser()
     parser.add_argument('-c', '--config_uri', required=True, help='Configuration file, e.g., development.ini')
@@ -33,9 +32,10 @@ def parse_args(argv):
     parser.add_argument('-ak', '--initial-api-key', required=False, type=str, help='Initial API key for testing purposes')
     return parser.parse_args(argv[1:])
 
+
 def create_api_key(request, key):
     db = request.dbsession
-    user = db.query(User).one_or_none();
+    user = db.query(User).one_or_none()
     assert user, "No or multiple users found in database, cannot create API key"
 
     api_key = ApiKey(
@@ -46,6 +46,7 @@ def create_api_key(request, key):
             )
     db.add(api_key)
 
+
 def create_initial_user(request, email, fullname, password, groupname):
     from .. import siteid
 
@@ -71,6 +72,7 @@ def create_initial_user(request, email, fullname, password, groupname):
                 )
         db.add(root)
 
+
 def create_example_metadata(dbsession):
     if dbsession.query(MetaDatum).first() is None:
         metadata = [
@@ -119,6 +121,7 @@ def create_example_metadata(dbsession):
                 ]
         dbsession.add_all(metadata)
 
+
 def main(argv=sys.argv):
     args = parse_args(argv)
 
@@ -135,7 +138,7 @@ def main(argv=sys.argv):
                 sys.exit(0)
 
             # Check that specified defaults aren't empty strings (e.g. from the shipped compose file)
-            for arg in ['initial_user_fullname','initial_user_email','initial_user_pass','initial_group']:
+            for arg in ['initial_user_fullname', 'initial_user_email', 'initial_user_pass', 'initial_group']:
                 if not vars(args)[arg]:
                     sys.exit(f"Please specify a valid string for '{arg}'!")
 
