@@ -226,7 +226,7 @@ DataMeta.submit.buildKeyColunns = function(fileKeys, keys) {
         if (fileKeys.includes(key)) {
             /* FILE VALUES */
             columns.push({ title:key, data:null, render:function(metadataset) {
-                var str = metadataset.record[key].value === null ? '<span class="text-black-50"><i>empty</i></span>' : metadataset.record[key].value;
+                var str = metadataset.record[key] === null ? '<span class="text-black-50"><i>empty</i></span>' : metadataset.record[key];
                 return '<span data-datameta-class="field-status" data-datameta-uuid="'+metadataset.id.uuid+'" data-datameta-field="'+key+'">' +
                     '<i class="bi bi-hdd-rack-fill text-secondary" data-datameta-class="status-none" style="display:inline"></i>' +
                     '<i class="bi bi-hdd-rack-fill text-danger" data-datameta-class="status-err" style="display:none"></i>' +
@@ -237,7 +237,7 @@ DataMeta.submit.buildKeyColunns = function(fileKeys, keys) {
         } else {
             /* NON-FILE VALUES */
             columns.push({ title:key, data:"record", render: function(record) {
-                var str = record[key].value === null ? '<span class="text-black-50"><i>empty</i></span>' : record[key].value;
+                var str = record[key] === null ? '<span class="text-black-50"><i>empty</i></span>' : record[key];
                 return str;
             }});
         }
@@ -293,7 +293,7 @@ DataMeta.submit.showMetaErrors = function(metadata, errors) {
         if (response.ok) return response.json()
         throw new Error();
     }).then(function(json) {
-        var keys = json.map(metadatum => metadatum.name);
+        var keys = json.filter(mdatum => mdatum.serviceId === null).map(metadatum => metadatum.name);
         var columns = [ DataMeta.submit.statusColumn ].concat(DataMeta.submit.buildKeyColunns([], keys));
         var card_failed = document.getElementById("card_failed");
         card_failed.classList.remove("d-none");
@@ -477,7 +477,7 @@ DataMeta.submit.renderMetadataHelp = function() {
         if (response.ok) return response.json();
         throw new Error();
     }).then(function(json) {
-        html_chunks = json.map(function(metadatum) {
+        html_chunks = json.filter(mdat => mdat.serviceId === null).map(function(metadatum) {
             var html='<li href="#" class="list-group-item list-group-item-action" aria-current="true" style="background-color:transparent"><div class="d-flex w-100 justify-content-between"><h6 class="mb-1 text-success"><strong>'
             html += metadatum.name
             html += '</strong></h6>';
